@@ -31,3 +31,8 @@ class DescribeTenantUserRolesRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_TenantId(self): # String
+		return self.get_body_params().get('TenantId')
+
+	def set_TenantId(self, TenantId):  # String
+		self.add_body_params('TenantId', TenantId)
